============
Installation
============

At the command line::

    $ git clone https://github.com/mgieles/limepy.git
    $ cd limepy
    $ python setup.py install

or::
  
    $ pip install astro-limepy 

If you do not have root access, add --user to the pip install command.
 
